﻿/*----------------------------------------------------------------
//  <copyright file="Function_Demo.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-10-14 17:14</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using System.ComponentModel;

namespace EaCloud.Template.Pack.Demo.Core.Database
{
    #region "数据库函数：Function_Demo"
    /// <summary>
    /// 数据库函数：Function_Demo
    /// </summary>
    [Description("数据库函数示例")]
    public class Function_Demo : IDatabaseFunction
    {
        #region "方法"
        #region "获取函数架构"
        /// <summary>
        /// 获取函数架构
        /// </summary>
        public string GetFunctionSchema()
        {
            return "es_demo";
        }
        #endregion
        #region "获取函数名称"
        /// <summary>
        /// 获取函数名称
        /// </summary>
        public string GetFunctionName()
        {
            return "Function_Demo";
        }
        #endregion
        #region "获取创建脚本"
        /// <summary>
        /// 获取创建脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetCreateScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"Create FUNCTION [{GetFunctionSchema()}].[{GetFunctionName()}]
(
    @plantID int
    , @CheckTime datetime --考勤时间
    , @deptID int --部门
    , @wShop int --工段
    , @roleID int --岗位
    , @wGroup int --班组
    , @uID int --员工
)
RETURNS @retValue Table (atWork datetime, offWork datetime)
AS
BEGIN
    Declare @onTime datetime
    , @offTime datetime
    
    --......

    Set @onTime = '2016-07-01 08:00'
    Set @offTime = '2016-07-01 17:00'

    Insert Into @retValue(atWork, offWork)
    Values(@onTime, @offTime)

    Return
END";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取更改脚本"
        /// <summary>
        /// 获取更改脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetAlterScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"ALTER FUNCTION [{GetFunctionSchema()}].[{GetFunctionName()}]
(
    @plantID int
    , @CheckTime datetime --考勤时间
    , @deptID int --部门
    , @wShop int --工段
    , @roleID int --岗位
    , @wGroup int --班组
    , @uID int --员工
)
RETURNS @retValue Table (atWork datetime, offWork datetime)
AS
BEGIN
    Declare @onTime datetime
    , @offTime datetime
    
    --......
    --......

    -- Set @onTime = '2016-07-01 08:00' --版本1.0
    -- Set @offTime = '2016-07-01 17:00'    --版本1.0
    Set @onTime = '2016-07-01 08:00'    --版本1.1
    Set @offTime = '2016-07-01 17:00'   --版本1.1

    Insert Into @retValue(atWork, offWork)
    Values(@onTime, @offTime)

    Return
END";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取删除脚本"
        /// <summary>
        /// 获取删除脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetDropScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"DROP FUNCTION [{GetFunctionSchema()}].[{GetFunctionName()}]";
                    break;
            }
            return script;
        }
        #endregion

        #endregion

    }
    #endregion

}
