﻿/*----------------------------------------------------------------
//  <copyright file="Procedure_Demo.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-10-14 17:14</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using System.ComponentModel;

namespace EaCloud.Template.Pack.Demo.Core.Database
{
    #region "数据库存储过程：Procedure_Demo"
    /// <summary>
    /// 数据库存储过程：Procedure_Demo
    /// </summary>
    [Description("数据库存储过程示例")]
    public class Procedure_Demo : IDatabaseProcedure
    {
        #region "方法"
        #region "获取存储过程架构"
        /// <summary>
        /// 获取存储过程架构
        /// </summary>
        public string GetProcedureSchema()
        {
            return "es_demo";
        }
        #endregion
        #region "获取存储过程名称"
        /// <summary>
        /// 获取存储过程名称
        /// </summary>
        public string GetProcedureName()
        {
            return "Procedure_Demo";
        }
        #endregion
        #region "获取创建脚本"
        /// <summary>
        /// 获取创建脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetCreateScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"create procedure [{GetProcedureSchema()}].[{GetProcedureName()}]
as
begin
    select 1 AS [Id],GETDATE() AS [TimeNow]
end";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取更改脚本"
        /// <summary>
        /// 获取更改脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetAlterScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"ALTER procedure [{GetProcedureSchema()}].[{GetProcedureName()}]
as
begin
    -- select 1 AS [Id],GETDATE() AS [TimeNow]  --版本1.0
    select 2 AS [Id],GETDATE() AS [TimeNow] --版本1.1
end";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取删除脚本"
        /// <summary>
        /// 获取删除脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetDropScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"DROP PROCEDURE [{GetProcedureSchema()}].[{GetProcedureName()}]";
                    break;
            }
            return script;
        }
        #endregion

        #endregion

    }
    #endregion

}
