﻿/*----------------------------------------------------------------
//  <copyright file="Trigger_Demo.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-10-14 17:14</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using System.ComponentModel;

namespace EaCloud.Template.Pack.Demo.Core.Database
{
    #region "数据库触发器：Trigger_Demo"
    /// <summary>
    /// 数据库触发器：Trigger_Demo
    /// </summary>
    [Description("数据库触发器示例")]
    public class Trigger_Demo : IDatabaseTrigger
    {
        #region "方法"
        #region "获取数据库架构"
        /// <summary>
        /// 获取数据库架构
        /// </summary>
        public string GetDbSchema()
        {
            return "es_demo";
        }
        #endregion
        #region "获取触发器名称"
        /// <summary>
        /// 获取触发器名称
        /// </summary>
        public string GetTriggerName()
        {
            return "Trigger_Demo";
        }
        #endregion
        #region "获取实体表名称"
        /// <summary>
        /// 获取实体表名称
        /// </summary>
        public string GetTableName()
        {
            return "DMO_DemoEntity";
        }
        #endregion
        #region "获取创建脚本"
        /// <summary>
        /// 获取创建脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetCreateScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"CREATE TRIGGER [{GetDbSchema()}].[{GetTriggerName()}]
   ON  [{GetDbSchema()}].[{GetTableName()}]
   AFTER INSERT
AS 
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	print 'Hello';

    -- Insert statements for trigger here

END";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取更改脚本"
        /// <summary>
        /// 获取更改脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetAlterScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"ALTER TRIGGER [{GetDbSchema()}].[{GetTriggerName()}]
   ON  [{GetDbSchema()}].[{GetTableName()}]
   AFTER INSERT
AS 
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	-- print 'Hello';   --版本1.0
	print 'Hello';  --版本1.1

    -- Insert statements for trigger here

END";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取删除脚本"
        /// <summary>
        /// 获取删除脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetDropScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"DROP TRIGGER [{GetDbSchema()}].[{GetTriggerName()}]";
                    break;
            }
            return script;
        }
        #endregion

        #endregion

    }
    #endregion

}
