﻿/*----------------------------------------------------------------
//  <copyright file="DemoView.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-10-14 17:15</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Entity;
using System;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations.Schema;

namespace EaCloud.Template.Pack.Demo.Core.Entities
{
    #region "实体类：DemoView"
    /// <summary>
    /// 实体类：DemoView
    /// </summary>
    [Entity("DemoView")]
    [EntityNamePrefix("DMO")]
    [EntitySchema("demo")]
    [Description("实体视图示例")]
    [DatabaseView]
    public class DemoView : EntityBase<int>, IDatabaseView
    {
        #region "属性"
        #region "获取或设置 当前时间 DateTime"
        /// <summary>
        /// 获取或设置 当前时间
        /// </summary>
        [Column("DateTimeNow")]
        [DisplayName("当前时间")]
        public DateTime DateTimeNow { get; set; }
        #endregion

        #endregion

        #region "方法"
        #region "获取视图架构"
        /// <summary>
        /// 获取视图架构
        /// </summary>
        public string GetViewSchema()
        {
            return "es_demo";
        }
        #endregion
        #region "获取视图名称"
        /// <summary>
        /// 获取视图名称
        /// </summary>
        public string GetViewName()
        {
            return "DemoView";
        }
        #endregion
        #region "获取创建脚本"
        /// <summary>
        /// 获取创建脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetCreateScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    // 重要：如果系统中定义了 Entity 实体通过 DataBaseViewAttribute 属性映射，请保证脚本返回的字段与 Entity 属性映射保持一致。
                    script = @$"CREATE VIEW [{GetViewSchema()}].[{GetViewName()}] 
AS
/* Database：{databaseType}*/
SELECT 1 AS [Id],GETDATE() AS [DateTimeNow]
";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取更改脚本"
        /// <summary>
        /// 获取更改脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetAlterScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    // 重要：如果系统中定义了 Entity 实体通过 DataBaseViewAttribute 属性映射，请保证脚本返回的字段与 Entity 属性映射保持一致。
                    script = @$"ALTER VIEW [{GetViewSchema()}].[{GetViewName()}] 
AS
/* Database：{databaseType}*/
-- SELECT 1 AS [Id],GETDATE() AS [DateTimeNow]  --版本1.0
SELECT 2 AS [Id],GETDATE() AS [DateTimeNow] --版本1.1
";
                    break;
            }
            return script;
        }
        #endregion
        #region "获取删除脚本"
        /// <summary>
        /// 获取删除脚本
        /// </summary>
        /// <param name="databaseType">数据库类型</param>
        public string GetDropScript(DatabaseType databaseType)
        {
            var script = "";
            //可根据不同的数据库类型返回对应的脚本
            switch (databaseType)
            {
                case DatabaseType.MySql:
                case DatabaseType.Oracle:
                case DatabaseType.PostgreSql:
                case DatabaseType.Sqlite:
                case DatabaseType.SqlServer:
                    script = @$"DROP VIEW [{GetViewSchema()}].[{GetViewName()}]";
                    break;
            }
            return script;
        }
        #endregion

        #endregion

    }
    #endregion

}
