﻿/*----------------------------------------------------------------
//  <copyright file="DemoEntityConfiguration.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-10-13 09:18</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Entity;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using DemoEntity = EaCloud.Template.Pack.Demo.Core.Entities.DemoEntity;

namespace EaCloud.Template.Pack.Demo.EntityConfiguration
{
    #region "DemoEntity实体映射配置"
    /// <summary>
    /// DemoEntity实体映射配置
    /// </summary>
    public partial class DemoEntityConfiguration : EntityTypeConfigurationBase<DemoEntity, long>
    {
        #region "方法"
        #region "重写以实现实体类型各个属性的数据库配置"
        /// <summary>
        /// 重写以实现实体类型各个属性的数据库配置
        /// </summary>
        /// <param name="builder">实体类型创建器</param>
        public override void Configure(EntityTypeBuilder<DemoEntity> builder)
        {
            builder.HasIndex(m => new { m.String, m.DeletedTime }).HasDatabaseName("IDX_DemoEntity_String").IsUnique().HasFilter(null);
            builder.HasIndex(m => m.Guid).HasDatabaseName("IDX_DemoEntity_Guid").IsUnique();
            builder.HasIndex(m => m.OrganizationId).HasDatabaseName("IX_DemoEntity_OrganizationId").IsUnique(false);

            //外键配置示例（具体参考EF Core相关文档）
            //builder.HasOne(ur => ur.MainTable).WithMany().HasForeignKey(m => m.MainTableId).HasConstraintName("FK_Demo_XXX").IsRequired();
            //builder.HasOne(ur => ur.MainTable).WithMany(r => r.SubTableList).HasForeignKey(m => m.MainTableId).HasConstraintName("FK_Demo_XXXX").IsRequired(false);

            EntityConfigurationAppend(builder);
        }
        #endregion
        #region "额外的数据映射"
        /// <summary>
        /// 额外的数据映射
        /// </summary>
        /// <param name="builder"></param>
        partial void EntityConfigurationAppend(EntityTypeBuilder<DemoEntity> builder);
        #endregion

        #endregion

    }
    #endregion

}
