﻿/*----------------------------------------------------------------
//  <copyright file="UpgradeController.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2022-03-30 11:54</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.AspNetCore.UI;
using EaCloud.Authorization.Modules;
using EaCloud.IO;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System;
using System.ComponentModel;
using System.IO;
using System.Net;
using System.Net.Mime;
using System.Xml;

namespace EaCloud.Template.Svc.Controllers
{
    #region "应用升级Api控制器"
    /// <summary>
    /// 应用升级Api控制器
    /// </summary>
    [Description("网站-应用升级管理")]
    [AllowAnonymous]
    [ApiExplorerSettings(GroupName = "buss")]
    [ModuleInfo(Code = "Upgrade", Name = "应用升级管理", Order = 1)]
    public class UpgradeController : SiteApiControllerBase
    {
        #region "常量"
        #region "获取 应用升级配置目录"
        /// <summary>
        /// 获取 应用升级配置目录
        /// </summary>
        protected const string UpgradeDirectory = @"Upgrades";
        #endregion
        #region "获取 应用包存放目录"
        /// <summary>
        /// 获取 应用包存放目录
        /// </summary>
        protected const string UpgradePackageDirectory = @"Packages";
        #endregion
        #region "获取 应用升级配置内容"
        /// <summary>
        /// 获取 应用升级配置内容
        /// </summary>
        protected const string UpgradesName = @"Upgrades.xml";
        #endregion
        #region "获取 应用升级配置内容"
        /// <summary>
        /// 获取 应用升级配置内容
        /// </summary>
        protected const string UpgradesContent = @"<?xml version=""1.0"" encoding=""utf-8"" ?>
<!-- 应用集合 -->
<Upgrades>
	<!-- 应用信息说明 -->
	<!--<Upgrade AppId = ""应用APPID"" Name=""应用名称"" Descript=""应用描述"" Version=""版本名称"" VersionCode=""版本号"" Author=""作者"" Email=""电子邮箱"" Platform=""客户端平台""
		  AppStoreLink=""是否请求AppStore链接"" Upgrade=""是否需要升级（同一AppId 只能有一个ture，多个时只会取第一个）"" Force=""强制升级"" Silent=""静默升级"" Wgt=""是否Wgt（增量）"" Url=""包地址""
		  Title=""标题"" Content=""内容""/>-->
	<!-- 应用信息示例 -->
	<!--<Upgrade AppId = ""__UNI__81B3E10"" Name=""eacloud-app-pda"" Descript=""易云PDA快速开发框架"" Version=""1.0.1"" VersionCode=""101"" Author=""SeonHu"" Email=""SeonHu@126.com"" Platform=""android""
			AppStoreLink=""false"" Upgrade=""true"" Force=""false"" Silent=""false"" Wgt=""false"" Url=""包地址，例如：/api/upgrade/download?file=eacloud-app-pda.apk""
			Title=""优化更新"" Content=""1.优化的相关业务交货场景；
2.顺便开除了一个程序员。""/>-->

</Upgrades>
";
        #endregion

        #endregion

        #region "DTO"
        #region "升级检测DTO"
        /// <summary>
        /// 升级检测DTO
        /// </summary>
        public class UpgradeCheckDto
        {
            #region "属性"
            #region "获取或设置 方法"
            /// <summary>
            /// 获取或设置 方法
            /// </summary>
            public string Method { get; set; } = "upgrade";
            #endregion
            #region "获取或设置 应用APPID"
            /// <summary>
            /// 获取或设置 应用APPID
            /// </summary>
            public string AppId { get; set; }
            #endregion
            #region "获取或设置 应用名称"
            /// <summary>
            /// 获取或设置 应用名称
            /// </summary>
            public string Name { get; set; }
            #endregion
            #region "获取或设置 应用描述"
            /// <summary>
            /// 获取或设置 应用描述
            /// </summary>
            public string Descript { get; set; }
            #endregion
            #region "获取或设置 版本名称"
            /// <summary>
            /// 获取或设置 版本名称
            /// </summary>
            public string Version { get; set; }
            #endregion
            #region "获取或设置 版本号"
            /// <summary>
            /// 获取或设置 版本号
            /// </summary>
            public string VersionCode { get; set; }
            #endregion
            #region "获取或设置 应用的作者"
            /// <summary>
            /// 获取或设置 应用的作者
            /// </summary>
            public string Author { get; set; }
            #endregion
            #region "获取或设置 应用的电子邮箱"
            /// <summary>
            /// 获取或设置 应用的电子邮箱
            /// </summary>
            public string Email { get; set; }
            #endregion
            #region "获取或设置 客户端平台"
            /// <summary>
            /// 获取或设置 客户端平台
            /// </summary>
            public string Platform { get; set; }
            #endregion

            #region "获取或设置 是否请求AppStore链接"
            /// <summary>
            /// 获取或设置 是否请求AppStore链接
            /// </summary>
            public bool AppStoreLink { get; set; }
            #endregion

            #endregion
        }
        #endregion
        #region "升级检测结果DTO"
        /// <summary>
        /// 升级检测结果DTO
        /// </summary>
        public class UpgradeCheckResultDto
        {
            #region "属性"
            #region "获取或设置 是否需要升级"
            /// <summary>
            /// 获取或设置 是否需要升级
            /// </summary>
            public bool Upgrade { get; set; }
            #endregion
            #region "获取或设置 强制升级"
            /// <summary>
            /// 获取或设置 强制升级
            /// </summary>
            public bool Force { get; set; }
            #endregion
            #region "获取或设置 静默升级"
            /// <summary>
            /// 获取或设置 静默升级
            /// </summary>
            public bool Silent { get; set; }
            #endregion
            #region "获取或设置 是否AppStore链接"
            /// <summary>
            /// 获取或设置 是否AppStore链接
            /// </summary>
            public bool AppStoreLink { get; set; }
            #endregion
            #region "获取或设置 是否Wgt（增量）升级"
            /// <summary>
            /// 获取或设置 是否Wgt（增量）升级
            /// </summary>
            public bool WgtUpgrade { get; set; }
            #endregion
            #region "获取或设置 升级包大小"
            /// <summary>
            /// 获取或设置 升级包大小
            /// </summary>
            public long Size { get; set; }
            #endregion

            #region "获取或设置 版本名称"
            /// <summary>
            /// 获取或设置 版本名称
            /// </summary>
            public string Version { get; set; }
            #endregion
            #region "获取或设置 版本号"
            /// <summary>
            /// 获取或设置 版本号
            /// </summary>
            public string VersionCode { get; set; }
            #endregion
            #region "获取或设置 应用的作者"
            /// <summary>
            /// 获取或设置 应用的作者
            /// </summary>
            public string Author { get; set; }
            #endregion
            #region "获取或设置 应用的电子邮箱"
            /// <summary>
            /// 获取或设置 应用的电子邮箱
            /// </summary>
            public string Email { get; set; }
            #endregion
            #region "获取或设置 客户端平台"
            /// <summary>
            /// 获取或设置 客户端平台
            /// </summary>
            public string Platform { get; set; }
            #endregion

            #region "获取或设置 升级包地址"
            /// <summary>
            /// 获取或设置 升级包地址
            /// </summary>
            public string Url { get; set; }
            #endregion

            #region "获取或设置 升级标题"
            /// <summary>
            /// 获取或设置 升级标题
            /// </summary>
            public string UpgradeTitle { get; set; }
            #endregion
            #region "获取或设置 升级内容"
            /// <summary>
            /// 获取或设置 升级内容
            /// </summary>
            public string UpgradeContent { get; set; }
            #endregion

            #endregion
        }
        #endregion

        #endregion

        #region "Action方法"
        #region "升级检测"
        /// <summary>
        /// 升级检测
        /// </summary>
        /// <param name="dto">升级检测DTO</param>
        /// <returns></returns>
        [HttpPost]
        [ModuleInfo]
        [Description("升级检测")]
        public virtual AjaxResult Check(UpgradeCheckDto dto)
        {
            //验证提交的信息
            Data.Check.NotNull(dto, nameof(dto));
            //Data.Check.NotNullOrEmpty(dto.AppId, nameof(dto.AppId));
            //Data.Check.NotNullOrEmpty(dto.Version, nameof(dto.Version));

            //设置目录及初始项
            //var defRootPath = Path.Combine(Directory.GetCurrentDirectory(), FileConstants.DefaultRootDirectory);
            var baseRootPath = DirectoryHelper.RootPath();
            var upgradePath = Path.Combine(baseRootPath, UpgradeDirectory);
            DirectoryHelper.CreateIfNotExists(upgradePath);
            var upgradePackagePath = Path.Combine(upgradePath, UpgradePackageDirectory);
            DirectoryHelper.CreateIfNotExists(upgradePackagePath);

            XmlDocument xmlDocument = new();
            var upgradeFilePath = Path.Combine(upgradePath, UpgradesName);
            if (!System.IO.File.Exists(upgradeFilePath))
            {
                xmlDocument.LoadXml(UpgradesContent);
                xmlDocument.Save(upgradeFilePath);
            }
            else
            {
                xmlDocument.Load(upgradeFilePath);
            }

            var resultDto = new UpgradeCheckResultDto
            {
                Upgrade = false,
                Force = false,
                Silent = false,
                AppStoreLink = false,
                WgtUpgrade = false,
                Size = 0,
                Version = "1.0.0",
                VersionCode = "100",
                Author = "",
                Email = "",
                Platform = "",
                Url = "",
                UpgradeTitle = "",
                UpgradeContent = @""
            };
            // var upgradeNode = xmlDocument.SelectSingleNode($"//Upgrades/Upgrade[@AppId='__UNI__81B3E10'][@Upgrade='true']");
            var upgradeNode = xmlDocument.SelectSingleNode($"//Upgrades/Upgrade[@AppId='{dto.AppId}'][@Platform='{dto.Platform}'][@Upgrade='true']");
            if (upgradeNode != null)
            {
                var versionVal = upgradeNode.GetAttributeValue("Version");
                if (versionVal != dto.Version)
                {
                    resultDto.Upgrade = true;
                }
                resultDto.Force = upgradeNode.GetAttributeValue("Force").CastTo(false);
                resultDto.Silent = upgradeNode.GetAttributeValue("Silent").CastTo(false);
                resultDto.AppStoreLink = upgradeNode.GetAttributeValue("AppStoreLink").CastTo(false);
                resultDto.WgtUpgrade = upgradeNode.GetAttributeValue("Wgt").CastTo(false);

                resultDto.Version = upgradeNode.GetAttributeValue("Version");
                resultDto.VersionCode = upgradeNode.GetAttributeValue("VersionCode");
                resultDto.Author = upgradeNode.GetAttributeValue("Author");
                resultDto.Email = upgradeNode.GetAttributeValue("Email");
                resultDto.Platform = upgradeNode.GetAttributeValue("Platform");

                resultDto.UpgradeTitle = upgradeNode.GetAttributeValue("Title");
                resultDto.UpgradeContent = upgradeNode.GetAttributeValue("Content");

                var fileName = upgradeNode.GetAttributeValue("Url");
                var filePath = Path.Combine(upgradePackagePath, fileName);
                if (System.IO.File.Exists(filePath))
                {
                    try
                    {
                        var fileInfo = new FileInfo(filePath);
                        // 如果文件存在
                        if (fileInfo.Exists)
                        {
                            //System.Diagnostics.FileVersionInfo info = System.Diagnostics.FileVersionInfo.GetVersionInfo(filePath);
                            //Console.WriteLine("文件名称=" + info.FileName);
                            //Console.WriteLine("产品名称=" + info.ProductName);
                            //Console.WriteLine("公司名称=" + info.CompanyName);
                            //Console.WriteLine("文件版本=" + info.FileVersion);
                            //Console.WriteLine("产品版本=" + info.ProductVersion);
                            //// 通常版本号显示为「主版本号.次版本号.生成号.专用部件号」
                            //Console.WriteLine("系统显示文件版本：" + info.ProductMajorPart + '.' + info.ProductMinorPart + '.' + info.ProductBuildPart + '.' + info.ProductPrivatePart);
                            //Console.WriteLine("文件说明=" + info.FileDescription);
                            //Console.WriteLine("文件语言=" + info.Language);
                            //Console.WriteLine("原始文件名称=" + info.OriginalFilename);
                            //Console.WriteLine("文件版权=" + info.LegalCopyright);

                            // Console.WriteLine("文件大小=" + Math.Ceiling(fileInfo.Length / 1024.0) + " KB");

                            resultDto.Size = fileInfo.Length;
                            resultDto.Url = $"/api/upgrade/download?file={fileName}";
                        }
                    }
                    catch { }
                }
                else
                {
                    resultDto.Url = fileName;
                }

            }

            return AjaxResult.Success(resultDto);
        }
        #endregion
        #region "升级下载"
        /// <summary>
        /// 升级下载
        /// </summary>
        /// <param name="file">文件名</param>
        /// <returns></returns>
        [HttpGet]
        [ModuleInfo]
        [Description("升级下载")]
        public virtual IActionResult Download(string file)
        {
            //验证提交的信息
            Data.Check.NotNullOrEmpty(file, nameof(file));

            //设置目录及初始项
            //var defRootPath = Path.Combine(Directory.GetCurrentDirectory(), FileConstants.DefaultRootDirectory);
            var baseRootPath = DirectoryHelper.RootPath();
            var upgradePath = Path.Combine(baseRootPath, UpgradeDirectory);
            DirectoryHelper.CreateIfNotExists(upgradePath);
            var upgradePackagePath = Path.Combine(upgradePath, UpgradePackageDirectory);
            DirectoryHelper.CreateIfNotExists(upgradePackagePath);

            var filePath = Path.Combine(upgradePackagePath, file);

            if (!System.IO.File.Exists(filePath))
            {
                return BadRequest($"{filePath} 不存在");
            }
            // 文件流的方式输出
            var stream = System.IO.File.OpenRead(filePath);
            // return File(stream, "application/vnd.android.package-archive", Path.GetFileName(filePath));
            // Don't display the untrusted file name in the UI. HTML-encode the value.
            // 不要在UI中显示不受信任的文件名。HTML对值进行编码。
            return File(stream, MediaTypeNames.Application.Octet, WebUtility.HtmlEncode(file));

            //// 虚拟文件地址输出下载
            //var addrUrl = "/bak/love.apk";
            //return File(addrUrl, "application/vnd.android.package-archive", Path.GetFileName(addrUrl));
        }
        #endregion

        #endregion

    }
    #endregion

}
