﻿/*----------------------------------------------------------------
//  <copyright file="Program.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2022-04-08 10:13</last-date>
//----------------------------------------------------------------*/

//#if NET6_0_OR_GREATER

using EaCloud.AspNetCore.Host;
using EaCloud.Template.Svc;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using System;

var builder = WebApplication.CreateBuilder(args);

// 配置Kestrel选项
builder.WebHost.ConfigureKestrel((context, options) =>
{
    //设置应用服务器Kestrel请求体最大值
    //获取或设置任何请求正文的最大允许大小（以字节为单位）。
    //当设置为null时，最大请求正文大小是无限的。
    //此限制对升级的连接没有影响，因为升级后的连接总是无限的。
    //这可以通过每个请求覆盖Microsoft.AspNetCore.Http.Features.IHttpMaxRequestBodySizeFeature. 
    //默认为30000000字节，约为28.6MB。
    options.Limits.MaxRequestBodySize = null;

    //配置Kestrel Host。Kestrel的默认监听端口是http5000、https5001。
    options.SetHost();

    options.Limits.KeepAliveTimeout = TimeSpan.FromSeconds(50);
    options.Limits.RequestHeadersTimeout = TimeSpan.FromSeconds(50);
});

////项目中需要在startup启动类中使用DbContext对数据库做一些操作的例外设置
////以解决错误：“Cannot resolve scoped service 'XXX' from root provider”
//builder.WebHost.UseDefaultServiceProvider(options => { options.ValidateScopes = false; });

//配置启动类
Startup startup = new();
startup.ConfigureServices(builder.Services);

var app = builder.Build();
startup.Configure(app);

//运行程序
app.Run();

//#else

//using EaCloud.AspNetCore.Host;
//using Microsoft.AspNetCore.Hosting;
//using Microsoft.Extensions.Hosting;
//using System;

//namespace EaCloud.Template.Svc
//{
//    /// <summary>
//    /// Program文件
//    /// </summary>
//    public class Program
//    {
//        /// <summary>
//        /// 程序主入口
//        /// </summary>
//        /// <param name="args"></param>
//        public static void Main(string[] args)
//        {
//            CreateHostBuilder(args).Build().Run();
//        }

//        /// <summary>
//        /// 构建web服务
//        /// </summary>
//        /// <param name="args"></param>
//        /// <returns></returns>
//        public static IHostBuilder CreateHostBuilder(string[] args) =>
//            Host.CreateDefaultBuilder(args)
//                .ConfigureWebHostDefaults(webBuilder =>
//                {
//                    webBuilder.ConfigureKestrel((context, options) =>
//                    {
//                        //设置应用服务器Kestrel请求体最大值
//                        //获取或设置任何请求正文的最大允许大小（以字节为单位）。
//                        //当设置为null时，最大请求正文大小是无限的。
//                        //此限制对升级的连接没有影响，因为升级后的连接总是无限的。
//                        //这可以通过每个请求覆盖Microsoft.AspNetCore.Http.Features.IHttpMaxRequestBodySizeFeature. 
//                        //默认为30000000字节，约为28.6MB。
//                        options.Limits.MaxRequestBodySize = null;

//                        //配置Kestrel Host。Kestrel的默认监听端口是http5000、https5001。
//                        options.SetHost();
//                    });
//                    webBuilder.UseStartup<Startup>().ConfigureKestrel((context, serverOptions) =>
//                    {
//                        serverOptions.Limits.KeepAliveTimeout = TimeSpan.FromSeconds(50);
//                        serverOptions.Limits.RequestHeadersTimeout = TimeSpan.FromSeconds(50);
//                    });
//                })
//            ////项目中需要在startup启动类中使用DbContext对数据库做一些操作的例外设置
//            ////以解决错误：“Cannot resolve scoped service 'XXX' from root provider”
//            //.UseDefaultServiceProvider(options => { options.ValidateScopes = false; })
//            ;

//    }

//}

//#endif
