﻿/*----------------------------------------------------------------
//  <copyright file="Startup.cs" company="三擎科技信息（常州）有限责任公司">
//      Copyright © 2020-2022 SANQING Corporation, All rights reserved.
//  </copyright>
//  <site>https://gitee.com/eacloud</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2022-04-08 10:23</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.AspNetCore;
using EaCloud.AspNetCore.Routing;
//using EaCloud.AspNetCore.SignalR;
using EaCloud.AutoMapper;
//using EaCloud.Baidu.Core;
using EaCloud.Database;
using EaCloud.Exceptionless;
using EaCloud.Hangfire;
using EaCloud.Log4Net;
using EaCloud.MiniProfiler;
//using EaCloud.NLog;
using EaCloud.Pack.Audit.Core;
using EaCloud.Pack.Authorization.Core;
using EaCloud.Pack.File.Core;
using EaCloud.Pack.Identity.Core;
using EaCloud.Pack.IM.Core;
using EaCloud.Pack.Report.Core;
using EaCloud.Pack.SMS.Core;
using EaCloud.Redis;
using EaCloud.Swagger;
//using EaCloud.Template.Pack.Demo.Core;
using EaCloud.Template.Svc.Startups;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;

namespace EaCloud.Template.Svc
{
    /// <summary>
    /// 程序启动类
    /// </summary>
    public class Startup
    {
        #region "配置服务，此方法由运行时调用。使用此方法可将服务添加到容器中。"
        /// <summary>
        /// 配置服务，此方法由运行时调用。使用此方法可将服务添加到容器中。
        /// This method gets called by the runtime. Use this method to add services to the container.
        /// </summary>
        /// <param name="services">指定服务描述符集合的协定</param>
        public void ConfigureServices(IServiceCollection services)
        {
            //添加数据库开发人员页面异常筛选器
            services.AddDatabaseDeveloperPageExceptionFilter();

            //自动加载所有模块，并指定排除特定模块
            //services.AddEaCloud().AddPacks(typeof(HangfirePack), typeof(RedisPack));

            //手动加载模块
            services.AddEaCloud()
                // 必要加载模块
                .AddPack<Log4NetPack>()
                //.AddPack<NLogPack>()  //注：NLog日志处理模块，和Log4日志模块相比多出 跟踪（Trace）日志级别，该级别在Log4中写入 调试（Debug）级别日志。
                .AddPack<AutoMapperPack>()
                //.AddPack<SignalRPack>()   //注：如果启用消息模块，就不需要单独启用SignalR模块，消息模块依赖SignalR模块，会执行联动启动。
                .AddPack<EndpointsPack>()
                .AddPack<MiniProfilerPack>()
                .AddPack<SwaggerPack>()
                .AddPack<RedisPack>()
                .AddPack<SqlServerDefaultDbContextMigrationPack>()
                .AddPack<DatabaseMigratePack>()
                .AddPack<HangfirePack>()
                .AddPack<AuthenticationPack>()
                .AddPack<FunctionAuthorizationPack>()
                .AddPack<DataAuthorizationPack>()
                .AddPack<AuditPack>()
                .AddPack<ExceptionlessPack>()
                .AddPack<InstantMessagePack>()   //注：基于SignalR模块的即时消息模块。
                .AddPack<SmsPack>()
                .AddPack<FilePack>()
                .AddPack<ReportPack>()
                //.AddPack<MenuPack>()  //后台菜单功能待完善中...
                //.AddPack<WorkflowPack>()
                // 可选加载模块，根据实际需要选择加载引用
                //.AddPack<BaiduPack>()
                //样例模块
                //.AddPack<DemoPack>()
                ;

        }
        #endregion

        #region "配置，此方法由运行时调用。使用此方法配置HTTP请求管道。"
        //#if NET6_0_OR_GREATER
        /// <summary>
        /// 配置，此方法由运行时调用。使用此方法配置HTTP请求管道。
        /// This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        /// </summary>
        /// <param name="app">用于配置HTTP管道和路由的web应用程序</param>
        public void Configure(WebApplication app)
        {
            // 有关运行应用程序的web宿主环境的信息
            IWebHostEnvironment env = app.Environment;
            //#else
            //        /// <summary>
            //        /// 配置，此方法由运行时调用。使用此方法配置HTTP请求管道。
            //        /// This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
            //        /// </summary>
            //        /// <param name="app">配置应用程序请求管道的机制</param>
            //        /// <param name="env">有关运行应用程序的web宿主环境的信息</param>
            //        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
            //        {
            //#endif
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();

                app.UseMigrationsEndPoint();
            }
            else
            {
                app.UseExceptionHandler("/Error");
                app.UseHsts();
                //app.UseHttpsRedirection(); // 启用HTTPS
            }

            //app.UseMiddleware<HostHttpCryptoMiddleware>();
            //app.UseMiddleware<JsonNoFoundHandlerMiddleware>();
            app.UseMiddleware<JsonExceptionHandlerMiddleware>()
                .UseDefaultFiles()
                .UseStaticFiles();
            app.UseEaCloud();

        }
        #endregion

    }

}
